@@ -6,8 +6,8 @@ my $timj = WWW::ThisIsMyJam->new();
 my @jams;
 for (my $page = 1;; ++$page) {
     my $r = $timj->jams({person => 'jamoftheday', page => $page});
-    push @jams, $r->{jams};
+    push @jams, @{$r->{jams}};
     last unless $r->{list}{hasMore};
 }
 
-# Do something with @jams.
+# Do something cool with @jams
